# Apache Sedona

This library is the Python wrapper for Apache Sedona.

Apache Sedona is a cluster computing system for processing large-scale spatial data.
Apache Sedona extends Apache Spark / SparkSQL with a set of out-of-the-box Spatial Resilient Distributed Datasets (SRDDs)/ SpatialSQL that efficiently load, process, and analyze large-scale spatial data across machines.

Please visit the official Apache Sedona website:
https://sedona.apache.org/

Development environment setup docs: https://sedona.apache.org/latest-snapshot/setup/compile/#run-python-test
